Enum AesKeyLd
#[repr(u8)]pub enum AesKeyLd {
B_0X0 = 0,
B_0X1 = 1,
}Variants
B_0X0 = 0
AES core is waiting for 128 random bits from the entropy sources for generating its key.
B_0X1 = 1
AES key register has been loaded with a random key.
Implementations